@@ -15,9 +15,7 @@
 #
 # You should have received a copy of the GNU Lesser General Public License along
 # with yams. If not, see <http://www.gnu.org/licenses/>.
-"""Some common constraint classes.
-
-"""
+"""Some common constraint classes."""
 
 __docformat__ = "restructuredtext en"
 
